#! /usr/bin/env node
'use strict';

var _ioAuthoringConfigService = require('./server/services/ioAuthoringConfigService');

var _ioAuthoringConfigService2 = _interopRequireDefault(_ioAuthoringConfigService);

var _ioAuthoringConfigManager = require('./server/managers/ioAuthoringConfigManager');

var _ioAuthoringConfigManager2 = _interopRequireDefault(_ioAuthoringConfigManager);

var _configUtil = require('./server/utils/configUtil');

var _configUtil2 = _interopRequireDefault(_configUtil);

var _winstonLogs = require('./server/utils/winstonLogs');

var _winstonLogs2 = _interopRequireDefault(_winstonLogs);

var _server = require('./server');

var _server2 = _interopRequireDefault(_server);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function main() {
  var key = void 0,
      value = void 0,
      args = process.argv.slice(2),
      argsString = args.toString(),
      commandInserted = argsString.replace(/,/g, ' ');

  var daemon = require("daemonize2").setup({
    main: "daemonServer.js",
    name: "ioauthoring",
    pidfile: "ioauthoring.pid",
    silent: true
  });

  daemon.on("starting", function () {
    console.log("Starting ioAuthoring...");
  }).on("stopping", function () {
    console.log("Stopping ioAuthoring...");
  }).on("stopped", function (pid) {
    console.log("ioAuthoring stopped.");
  }).on("running", function (pid) {
    console.log("ioAuthoring already running. PID: " + pid);
  }).on("notrunning", function () {
    console.log("ioAuthoring is not running");
  }).on("error", function (err) {
    console.log("ioAuthoring failed to start:  " + err.message);
  });

  _winstonLogs2.default.info('Command inserted: ioauthoring ' + commandInserted);

  switch (args[0]) {
    case 'start':
      daemon.start();
      break;

    case 'stop':
      daemon.stop();
      break;

    case 'status':
      var result = daemon.status();
      if (result == 0) {
        console.log('ioAuthoring is not running.');
      } else {
        console.log('ioAuthoring is running at pid:' + result);
      }
      break;

    case 'config':
      if (args[1]) {
        switch (args[1]) {
          case '-list':
            _ioAuthoringConfigService2.default.configList();
            break;

          case '-add':
            key = args[2];
            value = args[3];
            try {
              if (key && value) {
                var lowerKey = key.toLowerCase();
                _configUtil2.default.setConfigParam(lowerKey, value);
              } else {
                console.log('\nPlease provide values in following order:\n ioAuthoring config -add <key> <value>');
              }
            } catch (exception) {
              console.log(exception);
            }
            break;

          case '-remove':
            key = args[2];
            try {
              if (key) {
                var lowerKey = key.toLowerCase();
                _ioAuthoringConfigManager2.default.deleteConfig(lowerKey);
              } else {
                console.log('\nPlease provide values in following order:\n ioAuthoring config -remove <key>');
              }
            } catch (exception) {
              console.log(exception);
            }
            break;
          default:
            console.log('Invalid flag "' + args[1] + '"');
        }
      } else {
        _ioAuthoringConfigService2.default.configList();
      }
      break;
  }
}

main();